@@ -23,13 +23,7 @@ def read_config(file, ioconfig=ioconfig):
 def load_config(file_name, ioconfig=ioconfig):
     return cio.load_config(file_name, ioconfig=ioconfig)
     
-def load_extra_of(file_name, ioconfig=ioconfig):
-    root, ext = os.path.splitext(find_config(file_name, ioconfig=ioconfig))
-    
-    file_name = os.path.join(root+"_extra"+ext)
-    if not os.path.exists(file_name):
-        return None
-    return read_config(file_name)
+
 
 def load_map(file_name, ioconfig=ioconfig):
     return read_map(find_config(file_name, ioconfig=ioconfig))
@@ -53,6 +47,8 @@ def find_map(dev_type, ioconfig=ioconfig):
         raise IOError('coud not find map file of device %r from pydevmgr_elt package'%(dev_type))        
     return pkg_resources.resource_filename(pkg_name, os.path.join(ioconfig.resources, resource))
 
+
+
 _default_map_cash = {}
 def load_default_map(dev_type, ioconfig=ioconfig):
     """ load a map file according to a device type 
