@@ -1,4 +1,4 @@
-from pydevmgr_elt.devices.adc.stat import AdcStat as Stat
+from pydevmgr_elt.devices.adc.stat import AdcStat as Stat, AXIS, MODE
 from pydevmgr_elt.devices.adc.cfg  import AdcCfg as Cfg
 from pydevmgr_elt.devices.adc.rpcs import AdcRpcs as Rpcs
 
@@ -109,7 +109,9 @@ class Adc(Base):
     Cfg = Cfg
     Stat = Stat
     Rpcs = Rpcs
-    
+    AXIS = AXIS
+    MODE = MODE 
+
     class Data(Base.Data):
         Cfg = Cfg.Data
         Stat = Stat.Data
@@ -124,17 +126,6 @@ class Adc(Base):
     def motors(self) -> list:
         return (self.motor1, self.motor2)
     
-    def connect(self) -> None:
-        """ Connect all opc-ua client to servers """
-        super(Adc, self).connect()
-        for m in self.motors:
-            m.connect()
-    
-    def disconnect(self) -> None:
-        """ Disconnect client from their servers """
-        super(Adc, self).disconnect()
-        for m in self.motors:
-            m.disconnect()
             
     def get_configuration(self, exclude_unset=True, **kwargs) -> Dict[Base.Node,Any]:
         cfg_dict = {}
@@ -185,8 +176,8 @@ class Adc(Base):
             angle (float, optional): target angle default = 0.0 
             
         Returns:
-            is_standstill:  the :class:`NodeAlias` .stat.is_standstill to check if the device is 
-                            in standstill. (e.i. movement finished)
+            is_standstill (Node):  the :class:`NodeAlias` .stat.is_standstill to check if the device is 
+                                      in standstill. (e.i. movement finished)
         
         Example:
         
@@ -206,7 +197,7 @@ class Adc(Base):
             vel (float): target velocity 
         
         Returns:
-            is_standstill:  the :class:`NodeAlias` .stat.is_standstill to check if the device is in standstill
+            is_standstill (Node):  the :class:`NodeAlias` self.stat.is_standstill to check if the device is in standstill
         
         Example:
         
@@ -226,7 +217,7 @@ class Adc(Base):
             vel (float): target velocity 
         
         Returns:
-            is_standstill:  the :class:`NodeAlias` .stat.is_standstill to check if the device is in standstill
+            is_standstill (Node):  the :class:`NodeAlias` .stat.is_standstill to check if the device is in standstill
         
         Example:
         
